Module flags

Available on crate feature always_build_flagstable only.
Flags used when building this library

Constants

IS_AUTO_DETECT_DEFTRIG
Whether the default behavior autodetection was used for ManuallyDrop.
IS_BUILD_FLAGSTABLE
Whether a table of build flags to use was created when the library was compiled.
IS_FULLINTERNAL_DEBUG_ASSERTIONS
Enable additional internal checks of the SafeManuallyDrop library when the debug_assertions flag is enabled (does not depend on the always_check_in_case_debug_assertions and always_safe_manuallydrop options).
IS_INVALID_AUTO_DETECT_DEFTRIG
If the build was done using “all functions” (cargo test/doc/build –all-features), the required behavior in a safe mandrop cannot be determined, if this flag is active, EmptyLoopTrigManuallyDrop will be used.
IS_SAFE_MODE
Depending on the build flag, a protected version of ManuallyDrop or an unprotected version of ManuallyDrop with a default trigger.
IS_SUPPORT_ABORT_TRIG
Whether the library build flag was used to support abort_trig.
IS_SUPPORT_COUNT_TRIG
Whether the library build flag was used to support count_trig.
IS_SUPPORT_HOOKFN_TRIG
Whether the library build flag was used to support hookfn_trig.
IS_SUPPORT_LOOP_IS_TRIG
Ability to determine if an empty loop trigger has been executed.
IS_SUPPORT_LOOP_TRIG
Whether the library build flag was used to support loop_trig.
IS_SUPPORT_PANIC_TRIG
Whether the library build flag was used to support panic_trig.