Module hook

Available on crate feature support_hookfn_trig only.
Protected version of the SafeManuallyDrop with an execution function in case of undefined behavior of the ManuallyDrop logic.

Enums

HookFnTrigManuallyDrop
In case of undefined behavior of manual memory management, execute an external hook.

Functions

run_hook
Execute a hook function that is always executed in case of undefined behavior of the ManuallyDrop logic.
set_hook
Set a hook function to be executed in case of undefined behavior of ManuallyDrop logic.
take_hook
Get a hook function that will be executed in case of undefined behavior of the ManuallyDrop logic.

Type Aliases

AlwaysSafeHookManuallyDrop
Protected version of the SafeManuallyDrop with an execution function in case of undefined behavior of the ManuallyDrop logic.
AutoSafeHookManuallyDrop
Protected or unprotected version of ManuallyDrop with function execution in case of undefined behavior of ManuallyDrop logic.
HookFunction
The hook function to be executed in case of undefined behavior of the HookManuallyDrop.