Available on crate feature
always_build_flagstable only.Expand description
Flags used when building this library
Constants
- IS_
AUTO_ DETECT_ DEFTRIG - Whether the default behavior autodetection was used for ManuallyDrop.
- IS_
BUILD_ FLAGSTABLE - Whether a table of build flags to use was created when the library was compiled.
- IS_
FULLINTERNAL_ DEBUG_ ASSERTIONS - Enable additional internal checks of the SafeManuallyDrop library when the debug_assertions flag is enabled (does not depend on the always_check_in_case_debug_assertions and always_safe_manuallydrop options).
- IS_
INVALID_ AUTO_ DETECT_ DEFTRIG - If the build was done using “all functions” (cargo test/doc/build –all-features), the required behavior in a safe mandrop cannot be determined, if this flag is active, EmptyLoopTrigManuallyDrop will be used.
- IS_
SAFE_ MODE - Depending on the build flag, a protected version of ManuallyDrop or an unprotected version of ManuallyDrop with a default trigger.
- IS_
SUPPORT_ ABORT_ TRIG - Whether the library build flag was used to support abort_trig.
- IS_
SUPPORT_ COUNT_ TRIG - Whether the library build flag was used to support count_trig.
- IS_
SUPPORT_ HOOKFN_ TRIG - Whether the library build flag was used to support hookfn_trig.
- IS_
SUPPORT_ LOOP_ IS_ TRIG - Ability to determine if an empty loop trigger has been executed.
- IS_
SUPPORT_ LOOP_ TRIG - Whether the library build flag was used to support loop_trig.
- IS_
SUPPORT_ PANIC_ TRIG - Whether the library build flag was used to support panic_trig.