Available on crate feature
support_hookfn_trig only.Expand description
Protected version of the SafeManuallyDrop with an execution function in case of undefined behavior of the ManuallyDrop logic.
Enums
- Hook
FnTrig Manually Drop - In case of undefined behavior of manual memory management, execute an external hook.
Functions
- run_
hook - Execute a hook function that is always executed in case of undefined behavior of the ManuallyDrop logic.
- set_
hook ⚠ - Set a hook function to be executed in case of undefined behavior of ManuallyDrop logic.
- take_
hook - Get a hook function that will be executed in case of undefined behavior of the ManuallyDrop logic.
Type Aliases
- Always
Safe Hook Manually Drop - Protected version of the SafeManuallyDrop with an execution function in case of undefined behavior of the ManuallyDrop logic.
- Auto
Safe Hook Manually Drop - Protected or unprotected version of ManuallyDrop with function execution in case of undefined behavior of ManuallyDrop logic.
- Hook
Function - The hook function to be executed in case of undefined behavior of the HookManuallyDrop.